package at.xaxa.ledger.ui.home

import androidx.compose.foundation.ExperimentalFoundationApi
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import at.xaxa.ledger.ui.AppViewModelProvider
import at.xaxa.ledger.ui.ButtonSuccess
import at.xaxa.ledger.ui.HeaderCard
import at.xaxa.ledger.ui.HorizontalCard

@OptIn(ExperimentalFoundationApi::class)
@Composable
fun Home(modifier: Modifier = Modifier, onCardClick: (Int) -> Unit, onButtonClick: () -> Unit, HomeViewModel : HomeViewModel = viewModel(factory = AppViewModelProvider.Factory)) {
    val state by HomeViewModel.entryUIState.entry.collectAsState(initial = emptyList())

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        val items = (1..20).toList()
        LazyColumn(
            modifier = Modifier
                .weight(1f)
        ) {
            stickyHeader {
                HeaderCard(modifier = modifier, "-13563.00€")
            }
            items(items) { index ->
                Column(
                    modifier = Modifier.padding(vertical = 4.dp)
                ) {
                    HorizontalCard(
                        modifier = modifier,
                        name = "McDonald's $index",
                        date = "12th Feb, 23:32",
                        amount = "-12.99",
                        onClick = { onCardClick(index) }
                    )
                }
            }
        }

        // Sticky footer content
        Box(
            modifier = Modifier
                .fillMaxWidth(),
            contentAlignment = Alignment.Center
        ) {
            ButtonSuccess(modifier = Modifier, "Add Transaction", onClick = { onButtonClick() })
        }
    }
}
